@@ -17,6 +17,7 @@ from .academicearth import AcademicEarthCourseIE
 from .acast import (
     ACastIE,
     ACastChannelIE,
+    ACastPlayerIE,
 )
 from .adn import ADNIE
 from .adobeconnect import AdobeConnectIE
@@ -100,11 +101,13 @@ from .awaan import (
 )
 from .azmedien import AZMedienIE
 from .baidu import BaiduVideoIE
+from .bandaichannel import BandaiChannelIE
 from .bandcamp import BandcampIE, BandcampAlbumIE, BandcampWeeklyIE
 from .bbc import (
     BBCCoUkIE,
     BBCCoUkArticleIE,
-    BBCCoUkIPlayerPlaylistIE,
+    BBCCoUkIPlayerEpisodesIE,
+    BBCCoUkIPlayerGroupIE,
     BBCCoUkPlaylistIE,
     BBCIE,
 )
@@ -251,6 +254,7 @@ from .comedycentral import (
 )
 from .commonmistakes import CommonMistakesIE, UnicodeBOMIE
 from .commonprotocols import (
+    BitTorrentMagnetIE,
     MmsIE,
     RtmpIE,
 )
@@ -327,6 +331,7 @@ from .dropbox import DropboxIE
 from .dw import (
     DWIE,
     DWArticleIE,
+    DWVideoIE,
 )
 from .eagleplatform import EaglePlatformIE
 from .ebaumsworld import EbaumsWorldIE
@@ -703,7 +708,10 @@ from .mixcloud import (
     MixcloudUserIE,
     MixcloudPlaylistIE,
 )
-from .mlb import MLBIE
+from .mlb import (
+    MLBIE,
+    MLBVideoIE,
+)
 from .mnet import MnetIE
 from .moevideo import MoeVideoIE
 from .mofosex import (
@@ -911,6 +919,7 @@ from .packtpub import (
 from .pandoratv import PandoraTVIE
 from .parliamentliveuk import ParliamentLiveUKIE
 from .patreon import PatreonIE
+from .patronite import PatroniteAudioIE
 from .pbs import PBSIE
 from .pearvideo import PearVideoIE
 from .peertube import (
@@ -960,6 +969,9 @@ from .polskieradio import (
     PolskieRadioIE,
     PolskieRadioCategoryIE,
     PolskieRadioPlayerIE,
+    PolskieRadioPodcastIE,
+    PolskieRadioPodcastListIE,
+    PolskieRadioRadioKierowcowIE,
 )
 from .popcorntimes import PopcorntimesIE
 from .popcorntv import PopcornTVIE
@@ -1284,6 +1296,8 @@ from .threeqsdn import ThreeQSDNIE
 from .tiktok import (
     TikTokIE,
     TikTokUserIE,
+    TikTokHashtagIE,
+    TikTokMusicIE,
 )
 from .tinypic import TinyPicIE
 from .tmz import (
@@ -1365,10 +1379,6 @@ from .tver import TVerIE
 from .tvigle import TvigleIE
 from .tvland import TVLandIE
 from .tvn24 import TVN24IE
-from .tvnplayer import (
-    TVNPlayerIE,
-    TVNPlayerSeriesIE,
-)
 from .tvnet import TVNetIE
 from .tvnoe import TVNoeIE
 from .tvnow import (
@@ -1473,6 +1483,7 @@ from .videomore import (
     VideomoreSeasonIE,
 )
 from .videopress import VideoPressIE
+from .videotarget import VideoTargetIE
 from .vidio import VidioIE
 from .vidlii import VidLiiIE
 from .vidme import (
@@ -1624,6 +1635,8 @@ from .yandexmusic import (
     YandexMusicTrackIE,
     YandexMusicAlbumIE,
     YandexMusicPlaylistIE,
+    YandexMusicArtistTracksIE,
+    YandexMusicArtistAlbumsIE,
 )
 from .yandexvideo import YandexVideoIE
 from .yapfiles import YapFilesIE
@@ -1679,5 +1692,9 @@ from .zattoo import (
 )
 from .zdf import ZDFIE, ZDFChannelIE
 from .zhihu import ZhihuIE
-from .zingmp3 import ZingMp3IE
+from .zingmp3 import (
+    ZingMp3IE,
+    ZingMp3AlbumIE,
+)
+from .zoom import ZoomIE
 from .zype import ZypeIE
