@@ -2,6 +2,7 @@
 from __future__ import unicode_literals
 
 import itertools
+import json
 import re
 
 from .common import InfoExtractor
@@ -14,13 +15,44 @@ from ..utils import (
     extract_attributes,
     ExtractorError,
     int_or_none,
+    parse_iso8601,
     strip_or_none,
     unescapeHTML,
     unified_timestamp,
+    url_or_none,
 )
 
 
-class PolskieRadioIE(InfoExtractor):
+class PolskieRadioBaseExtractor(InfoExtractor):
+    def _extract_webpage_player_entries(self, webpage, playlist_id, base_data):
+        entries = []
+
+        media_urls = set()
+
+        for data_media in re.findall(r'<[^>]+data-media=(["\']?)({[^>]+})\1', webpage):
+            media = self._parse_json(unescapeHTML(data_media[1]), playlist_id, fatal=False)
+            if not media.get('file'):
+                continue
+            media_url = self._proto_relative_url(media['file'], 'https:')
+            if media_url in media_urls:
+                continue
+            media_urls.add(media_url)
+            entry = base_data.copy()
+            entry.update({
+                'id': compat_str(media['id']),
+                'url': media_url,
+                'duration': int_or_none(media.get('length')),
+                'vcodec': 'none' if media.get('provider') == 'audio' else None,
+            })
+            entry_title = compat_urllib_parse_unquote(media['desc'])
+            if entry_title:
+                entry['title'] = entry_title
+            entries.append(entry)
+
+        return entries
+
+
+class PolskieRadioIE(PolskieRadioBaseExtractor):
     _VALID_URL = r'https?://(?:www\.)?polskieradio(?:24)?\.pl/\d+/\d+/Artykul/(?P<id>[0-9]+)'
     _TESTS = [{
         # like data-media={"type":"muzyka"}
@@ -89,29 +121,13 @@ class PolskieRadioIE(InfoExtractor):
 
         thumbnail_url = self._og_search_thumbnail(webpage)
 
-        entries = []
-
-        media_urls = set()
-
         title = self._og_search_title(webpage).strip()
 
-        for data_media in re.findall(r'<[^>]+data-media=(["\']?)({[^>]+})\1', content):
-            media = self._parse_json(unescapeHTML(data_media[1]), playlist_id, fatal=False)
-            if not media.get('file'):
-                continue
-            media_url = self._proto_relative_url(media['file'], 'http:')
-            if media_url in media_urls:
-                continue
-            media_urls.add(media_url)
-            entries.append({
-                'id': compat_str(media['id']),
-                'url': media_url,
-                'title': compat_urllib_parse_unquote(media['desc']) or title,
-                'duration': int_or_none(media.get('length')),
-                'vcodec': 'none' if media.get('provider') == 'audio' else None,
-                'timestamp': timestamp,
-                'thumbnail': thumbnail_url
-            })
+        entries = self._extract_webpage_player_entries(content, playlist_id, {
+            'title': title,
+            'timestamp': timestamp,
+            'thumbnail': thumbnail_url,
+        })
 
         description = strip_or_none(self._og_search_description(webpage))
 
@@ -297,3 +313,122 @@ class PolskieRadioPlayerIE(InfoExtractor):
             'thumbnail': '%s/images/%s-color-logo.png' % (self._BASE_URL, channel_url),
             'is_live': True,
         }
+
+
+class PolskieRadioPodcastBaseExtractor(InfoExtractor):
+    _API_BASE = 'https://apipodcasts.polskieradio.pl/api'
+
+    def _parse_episode(self, data):
+        return {
+            'id': data['guid'],
+            'formats': [{
+                'url': data['url'],
+                'filesize': int_or_none(data.get('fileSize')),
+            }],
+            'title': data['title'],
+            'description': data.get('description'),
+            'duration': int_or_none(data.get('length')),
+            'timestamp': parse_iso8601(data.get('publishDate')),
+            'thumbnail': url_or_none(data.get('image')),
+            'series': data.get('podcastTitle'),
+            'episode': data['title'],
+        }
+
+
+class PolskieRadioPodcastListIE(PolskieRadioPodcastBaseExtractor):
+    IE_NAME = 'polskieradio:podcast:list'
+    _VALID_URL = r'https?://podcasty\.polskieradio\.pl/podcast/(?P<id>\d+)'
+    _TESTS = [{
+        'url': 'https://podcasty.polskieradio.pl/podcast/19/',
+        'info_dict': {
+            'id': '19',
+            'title': 'Raport o stanie świata',
+            'description': 'Autorski wybór najważniejszych wydarzeń politycznych, społecznych i kulturalnych ostatnich 7 dni na świecie. Z udziałem dziennikarzy, ekspertów, uczestników życia politycznego. Plus dobra muzyka i do tego na temat.',
+            'uploader': 'Dariusz Rosiak',
+        },
+        'playlist_count': 704,
+    }]
+
+    def _real_extract(self, url):
+        podcast_id = self._match_id(url)
+        data = self._download_json(
+            '%s/Podcasts/%s/?pageSize=10&page=1' % (self._API_BASE, podcast_id),
+            podcast_id, 'Downloading page #1')
+        entries = [self._parse_episode(ep) for ep in data['items']]
+        if len(entries) < data['itemCount']:
+            for page in range(2, data['itemCount'] // 10 + 2):
+                data = self._download_json(
+                    '%s/Podcasts/%s/?pageSize=10&page=%d' % (self._API_BASE, podcast_id, page),
+                    podcast_id, 'Downloading page #%d' % page)
+                entries.extend(self._parse_episode(ep) for ep in data['items'])
+        return {
+            '_type': 'playlist',
+            'entries': entries,
+            'id': str(data['id']),
+            'title': data['title'],
+            'description': data.get('description'),
+            'uploader': data.get('announcer'),
+        }
+
+
+class PolskieRadioPodcastIE(PolskieRadioPodcastBaseExtractor):
+    IE_NAME = 'polskieradio:podcast'
+    _VALID_URL = r'https?://podcasty\.polskieradio\.pl/track/(?P<id>[a-f\d]{8}(?:-[a-f\d]{4}){4}[a-f\d]{8})'
+    _TESTS = [{
+        'url': 'https://podcasty.polskieradio.pl/track/6eafe403-cb8f-4756-b896-4455c3713c32',
+        'info_dict': {
+            'id': '6eafe403-cb8f-4756-b896-4455c3713c32',
+            'ext': 'mp3',
+            'title': 'Theresa May rezygnuje. Co dalej z brexitem?',
+            'description': 'Brytyjska premier Theresa May zapowiedziała w piątek (24.05), że 7 czerwca ustąpi ze stanowiska szefowej Partii Konserwatywnej, uruchamiając proces wyboru jej następcy. Nowy szef torysów przejmie po niej także urząd premiera. ',
+        },
+    }]
+
+    def _real_extract(self, url):
+        podcast_id = self._match_id(url)
+        data = self._download_json(
+            '%s/audio' % (self._API_BASE),
+            podcast_id, 'Downloading podcast metadata',
+            data=json.dumps({
+                'guids': [podcast_id],
+            }).encode('utf-8'),
+            headers={
+                'Content-Type': 'application/json',
+            })
+        return self._parse_episode(data[0])
+
+
+class PolskieRadioRadioKierowcowIE(PolskieRadioBaseExtractor):
+    _VALID_URL = r'https?://(?:www\.)?radiokierowcow\.pl/artykul/(?P<id>[0-9]+)'
+    IE_NAME = 'polskieradio:kierowcow'
+
+    _TESTS = [{
+        'url': 'https://radiokierowcow.pl/artykul/2694529',
+        'info_dict': {
+            'id': '2694529',
+            'title': 'Zielona fala reliktem przeszłości?',
+            'description': 'md5:343950a8717c9818fdfd4bd2b8ca9ff2',
+        },
+        'playlist_count': 3,
+    }]
+
+    def _real_extract(self, url):
+        media_id = self._match_id(url)
+        webpage = self._download_webpage(url, media_id)
+        nextjs_build = self._search_nextjs_data(webpage, media_id)['buildId']
+        article = self._download_json(
+            'https://radiokierowcow.pl/_next/data/%s/artykul/%s.json?articleId=%s' % (nextjs_build, media_id, media_id),
+            media_id)
+        data = article['pageProps']['data']
+        title = data['title']
+        entries = self._extract_webpage_player_entries(data['content'], media_id, {
+            'title': title,
+        })
+
+        return {
+            '_type': 'playlist',
+            'id': media_id,
+            'entries': entries,
+            'title': title,
+            'description': data['lead'],
+        }
