@@ -45,7 +45,7 @@ def parseOpts(overrideArguments=None):
         except IOError:
             return default  # silently skip if file is not present
         try:
-            # FIXME: https://github.com/ytdl-org/haruhi-dl/commit/dfe5fa49aed02cf36ba9f743b11b0903554b5e56
+            # FIXME: https://github.com/ytdl-org/youtube-dl/commit/dfe5fa49aed02cf36ba9f743b11b0903554b5e56
             contents = optionf.read()
             if sys.version_info < (3,):
                 contents = contents.decode(preferredencoding())
@@ -165,6 +165,10 @@ def parseOpts(overrideArguments=None):
         '--force-generic-extractor',
         action='store_true', dest='force_generic_extractor', default=False,
         help='Force extraction to use the generic extractor')
+    general.add_option(
+        '--ie-key',
+        action='store', dest='ie_key', default=None,
+        help='Use the specified extractor (for performance improvements on some automated commands)')
     general.add_option(
         '--default-search',
         dest='default_search', metavar='PREFIX',
@@ -533,6 +537,19 @@ def parseOpts(overrideArguments=None):
         '--external-downloader-args',
         dest='external_downloader_args', metavar='ARGS',
         help='Give these arguments to the external downloader')
+    downloader.add_option(
+        '--allow-p2p',
+        dest='allow_p2p', action='store_true', default=None,
+        help='Allow downloading by peer-to-peer protocols (BitTorrent). '
+        'May be a violation of your local laws on file sharing in some cases')
+    downloader.add_option(
+        '--forbid-p2p',
+        dest='allow_p2p', action='store_false', default=None,
+        help='Explicitly forbid downloading by peer-to-peer protocols')
+    downloader.add_option(
+        '--prefer-p2p',
+        dest='prefer_p2p', action='store_true', default=None,
+        help='Prefer peer-to-peer formats (implies --allow-p2p)')
 
     workarounds = optparse.OptionGroup(parser, 'Workarounds')
     workarounds.add_option(
